[patch 6/9] s390: z90crypt reader task rescheduling.

From: Martin Schwidefsky
Date: Wed Mar 02 2005 - 11:53:26 EST


[patch 6/9] s390: z90crypt reader task rescheduling.

From: Eric Rossman <edrossma@xxxxxxxxxx>

z90crypt device driver changes:
- Correct the condition for which the reader task is scheduled to run.

Signed-off-by: Martin Schwidefsky <schwidefsky@xxxxxxxxxx>

diffstat:
drivers/s390/crypto/z90main.c | 6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)

diff -urN linux-2.6/drivers/s390/crypto/z90main.c linux-2.6-patched/drivers/s390/crypto/z90main.c
--- linux-2.6/drivers/s390/crypto/z90main.c 2005-03-02 08:37:30.000000000 +0100
+++ linux-2.6-patched/drivers/s390/crypto/z90main.c 2005-03-02 17:00:13.000000000 +0100
@@ -2657,8 +2657,8 @@

/**
* we use workavail = 2 to ensure 2 passes with nothing dequeued before
* exiting the loop. If pendingq_count == 0 after the loop, there is no
* work remaining on the queues.
*/
resp_addr = 0;
workavail = 2;
@@ -2697,7 +2697,7 @@
spin_unlock_irq(&queuespinlock);
}

- if (pendingq_count)
+ if (pendingq_count + requestq_count)
z90crypt_schedule_reader_timer();
}

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
@@ -2657,8 +2657,8 @@
/**
* we use workavail = 2 to ensure 2 passes with nothing dequeued before
- * exiting the loop. If pendingq_count == 0 after the loop, there is no
- * work remaining on the queues.
+ * exiting the loop. If (pendingq_count+requestq_count) == 0 after the
+ * loop, there is no work remaining on the queues.
*/
resp_addr = 0;
Please read the FAQ at http://www.tux.org/lkml/